fix(bigquery): minor rename to feature that's not yet in a release (#4320)

This adds a minor correction to Job's access to the underlying project.
While the access on the Client is more accurately called `Project()` as
it accepts project ID or project number, in this case the field is part
of the underlying JobReference type.

This was added yesterday in
https://github.com/googleapis/google-cloud-go/pull/4312 and hasn't made
it into a release cut yet, so addressing this now before release.
diff --git a/bigquery/job.go b/bigquery/job.go
index 725775d..6bdcbcc 100644
--- a/bigquery/job.go
+++ b/bigquery/job.go
@@ -63,8 +63,8 @@
 	return bqToJob(bqjob, c)
 }
 
-// Project returns the job's project.
-func (j *Job) Project() string {
+// ProjectID returns the job's associated project.
+func (j *Job) ProjectID() string {
 	return j.projectID
 }